searchData={"items":[{"type":"module","title":"Astro","doc":"Astrophysics in Elixir","ref":"Astro.html"},{"type":"module","title":"Astro.Ephemeris","doc":"Calculation state of objects","ref":"Astro.Ephemeris.html"},{"type":"module","title":"Aberration corrections - Astro.Ephemeris","doc":"Aberration correction argument in functions in this module may be any of the following:\n\n- `\"NONE\"` - Apply no correction. Return the geometric state of the target body relative to\n  the observer.\n\nThe following values of `abcorr` apply to the \"reception\" case in which photons depart from\nthe target's location at the light-time corrected epoch et-lt and *arrive* at the observer's\nlocation at `et`:\n\n- `\"LT\"` - Correct for one-way light time (also called \"planetary aberration\") using a\n  Newtonian formulation. This correction yields the state of the target at the moment it\n  emitted photons arriving at the observer at `et`. The light time correction uses an\n  iterative solution of the light time equation (see Particulars for details). The solution\n  invoked by the \"LT\" option uses one iteration.\n\n- `\"LT+S\"` - Correct for one-way light time and stellar aberration using a Newtonian\n  formulation. This option modifies the state obtained with the \"LT\" option to account for\n  the observer's velocity relative to the solar system barycenter. The result is the\n  apparent state of the target---the position and velocity of the target as seen by\n  the observer.\n\n- `\"CN\"` - Converged Newtonian light time correction. In solving the light time equation,\n  the \"CN\" correction iterates until the solution converges (three iterations on all\n  supported platforms). Whether the \"CN+S\" solution is substantially more accurate than\n  the \"LT\" solution depends on the geometry of the participating objects and on\n  the accuracy of the input data. In all cases this routine will execute more slowly when\n  a converged solution is computed. See the Particulars section below for a discussion of\n  precision of light time corrections.\n\n- `\"CN+S\"` - Converged Newtonian light time correction and stellar aberration correction.\n\nThe following values of `abcorr` apply to the \"transmission\" case in which photons *depart*\nfrom the observer's location at `et` and arrive at the target's location at the light-time\ncorrected epoch et+lt:\n\n- `\"XLT\"` - \"Transmission\" case: correct for one-way light time using a Newtonian\n  formulation. This correction yields the state of the target at the moment it receives\n  photons emitted from the observer's location at `et`.\n\n- `\"XLT+S\"` - \"Transmission\" case: correct for one-way light time and stellar aberration\n  using a Newtonian formulation  This option modifies the state obtained with the \"XLT\"\n  option to account for the observer's velocity relative to the solar system barycenter.\n  The position component of the computed target state indicates the direction that photons\n  emitted from the observer's location must be \"aimed\" to hit the target.\n\n- `\"XCN\"` - \"Transmission\" case: converged Newtonian light time correction.\n\n- `\"XCN+S\"` - \"Transmission\" case: converged Newtonian light time correction and stellar\n  aberration correction.\n\nNeither special nor general relativistic effects are accounted for in the aberration\ncorrections applied by this routine.","ref":"Astro.Ephemeris.html#module-aberration-corrections"},{"type":"function","title":"Astro.Ephemeris.conics/2","doc":"Determine state from conic elements\n\nDetermine the state (position, velocity) of an orbiting body from a set of elliptic, hyperbolic,\nor parabolic orbital elements.","ref":"Astro.Ephemeris.html#conics/2"},{"type":"function","title":"Input - Astro.Ephemeris.conics/2","doc":"- `elts` - are conic osculating elements describing the orbit of a body around a primary.\n  The elements are, in order:\n\n      RP      Perifocal distance.\n      ECC     Eccentricity.\n      INC     Inclination.\n      LNODE   Longitude of the ascending node.\n      ARGP    Argument of periapse.\n      M0      Mean anomaly at epoch.\n      T0      Epoch.\n      MU      Gravitational parameter.\n\n  Units are km, rad, rad/sec, km^3/sec^2.\n\n  The epoch `T0` is given in ephemeris seconds past J2000. `T0` is the instant at which the state\n  of the body is specified by the elements.\n\n  The same elements are used to describe all three types (elliptic, hyperbolic, and parabolic)\n  of conic orbit.\n\n- `et` - is the time at which the state of the orbiting body is to be determined, in ephemeris seconds\n  J2000.","ref":"Astro.Ephemeris.html#conics/2-input"},{"type":"function","title":"Output - Astro.Ephemeris.conics/2","doc":"- `state` - is the state (position and velocity) of the body at time `et`. Components are x, y, z,\n  dx/dt, dy/dt, dz/dt.\n\nMore info at\nhttps://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/conics_c","ref":"Astro.Ephemeris.html#conics/2-output"},{"type":"function","title":"Astro.Ephemeris.oscelt/3","doc":"Determine conic elements from state\n\nDetermine the set of osculating conic orbital elements that corresponds to the state (position,\nvelocity) of a body at some epoch.","ref":"Astro.Ephemeris.html#oscelt/3"},{"type":"function","title":"Input - Astro.Ephemeris.oscelt/3","doc":"- `state` - is the state (position and velocity) of the body at some epoch. Components are x, y,\n  z, dx/dt, dy/dt, dz/dt. `state` must be expressed relative to an inertial reference frame. Units\n  are km and km/sec.\n\n- `et` - is the epoch of the input state, in ephemeris seconds past J2000.\n- `mu` - is the gravitational parameter (GM, km^3 / sec^2 ) of the primary body.","ref":"Astro.Ephemeris.html#oscelt/3-input"},{"type":"function","title":"Output - Astro.Ephemeris.oscelt/3","doc":"- `elts` - are equivalent conic elements describing the orbit of the body around its primary. The\n  elements are, in order:\n\n      rp      Perifocal distance.\n      ecc     Eccentricity.\n      inc     Inclination.\n      lnode   Longitude of the ascending node.\n      argp    Argument of periapsis.\n      m0      Mean anomaly at epoch.\n      t0      Epoch.\n      mu      Gravitational parameter.\n\n  The epoch of the elements is the epoch of the input state. Units are km, rad, rad/sec. The same\n  elements are used to describe all three types (elliptic, hyperbolic, and parabolic) of conic\n  orbit.\n\nMore info at\nhttps://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/oscelt_c","ref":"Astro.Ephemeris.html#oscelt/3-output"},{"type":"function","title":"Astro.Ephemeris.spkez/5","doc":"Determine the apparent, true, or geometric state of a body with respect to another body relative\nto a user specified reference frame.\n\nReturn the state (position and velocity) of a target body relative to an observing body,\noptionally corrected for light time (planetary aberration) and stellar aberration.","ref":"Astro.Ephemeris.html#spkez/5"},{"type":"function","title":"Example - Astro.Ephemeris.spkez/5","doc":"Get geometric state of Earth relative to Solar System Barycenter in J2000 reference plane at\nthr current date\n\n    iex> now = DateTime.utc_now()\n    iex> jd = Astro.Time.to_julian_date(now)\n    iex> et = Astro.Time.day2sec(jd)\n    iex> Astro.Ephemeris.spkez(399, et, \"J2000\", \"NONE\", 0)\n    {:ok, [x, y, z, dx, dy, dz], lt}\n\nMore info at\nhttps://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/spkez_c","ref":"Astro.Ephemeris.html#spkez/5-example"},{"type":"function","title":"Astro.Ephemeris.spkezr/5","doc":"Determine the apparent, true, or geometric state of a body with respect to another body relative\nto a user specified reference frame.\n\nReturn the state (position and velocity) of a target body relative to an observing body,\noptionally corrected for light time (planetary aberration) and stellar aberration.","ref":"Astro.Ephemeris.html#spkezr/5"},{"type":"function","title":"Input - Astro.Ephemeris.spkezr/5","doc":"- `target` - is the name of a target body. Optionally, you may supply the integer ID code for\n    the object as an integer string. For example both \"MOON\" and \"301\" are legitimate strings that\n    indicate the moon is the target body.\n\n    The target and observer define a state vector whose position component points from\n    the observer to the target.\n\n  - `et` - is the ephemeris time, expressed as seconds past J2000 TDB, at which the state of\n    the target body relative to the observer is to be computed. `et` refers to time at\n    the observer's location.\n\n  - `ref_plane` - is the name of the reference frame relative to which the output state vector\n    should be expressed. This may be any frame supported by the SPICE system, including built-in\n    frames (documented in the Frames Required Reading) and frames defined by a loaded frame kernel\n    (FK).\n\n    When `ref_plane` designates a non-inertial frame, the orientation of the frame is evaluated at\n    an epoch dependent on the selected aberration correction. See the description of the output\n    state vector `starg` for details.\n\n  - `abcorr` - indicates the aberration corrections to be applied to the state of the target body\n    to account for one-way light time and stellar aberration. See Aberration corrections section\n    in module documentation.\n\n  - `obs` - is the name of an observing body. Optionally, you may supply the ID code of the object\n    as an integer string. For example, both \"EARTH\" and \"399\" are legitimate strings to supply to\n    indicate the observer is Earth.","ref":"Astro.Ephemeris.html#spkezr/5-input"},{"type":"function","title":"Output - Astro.Ephemeris.spkezr/5","doc":"- `state` - is a Cartesian state vector representing the position and velocity of the target\n    body relative to the specified observer. `state` is corrected for the specified aberrations,\n    and is expressed with respect to the reference frame specified by `ref`. The first three\n    components of `state` represent the x, y and z-components of the target's position; the last\n    three components form the corresponding velocity vector.\n\n    The position component of `state` points from the observer's location at `et` to the\n    aberration-corrected location of the target. Note that the sense of the position vector is\n    independent of the direction of radiation travel implied by the aberration correction.\n\n    The velocity component of `state` is the derivative with respect to time of the position\n    component of `state`.\n\n    Units are always km and km/sec.\n\n    Non-inertial frames are treated as follows: letting `ltcent` be the one-way light time between\n    the observer and the central body associated with the frame, the orientation of the frame is\n    evaluated at et-ltcent, et+ltcent, or `et` depending on whether the requested aberration\n    correction is, respectively, for received radiation, transmitted radiation, or is omitted.\n    `ltcent` is computed using the method indicated by `abcorr`.\n\n  - `lt` - is the one-way light time between the observer and target in seconds. If the target\n    state is corrected for aberrations, then `lt` is the one-way light time between the observer\n    and the light time corrected target location.","ref":"Astro.Ephemeris.html#spkezr/5-output"},{"type":"function","title":"Particulars - Astro.Ephemeris.spkezr/5","doc":"This routine is part of the user interface to the SPICE ephemeris system. It allows you to\nretrieve state information for any ephemeris object relative to any other in a reference frame\nthat is convenient for further computations.\n\nThis routine is identical in function to the routine `spkez` except that it allows you to refer to\nephemeris objects by name (via a character string).","ref":"Astro.Ephemeris.html#spkezr/5-particulars"},{"type":"function","title":"Example - Astro.Ephemeris.spkezr/5","doc":"Get geometric state of Earth relative to Solar System Barycenter in J2000 reference plane at\nthr current date\n\n    iex> now = DateTime.utc_now()\n    iex> jd = Astro.Time.to_julian_date(now)\n    iex> et = Astro.Time.day2sec(jd)\n    iex> Astro.Ephemeris.spkezr(\"EARTH\", et, \"J2000\", \"NONE\", \"SSB\")\n    {:ok, [x, y, z, dx, dy, dz], lt}\n\nMore info at\nhttps://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/spkezr_c","ref":"Astro.Ephemeris.html#spkezr/5-example"},{"type":"function","title":"Astro.Ephemeris.spkgeo/4","doc":"Compute the geometric state (position and velocity) of a target body relative to an observing\nbody.","ref":"Astro.Ephemeris.html#spkgeo/4"},{"type":"function","title":"Example - Astro.Ephemeris.spkgeo/4","doc":"Get geometric state of Earth relative to Solar System Barycenter in J2000 reference plane at\nthr current date\n\n    iex> now = DateTime.utc_now()\n    iex> jd = Astro.Time.to_julian_date(now)\n    iex> et = Astro.Time.day2sec(jd)\n    iex> Astro.Ephemeris.spkgeo(399, et, \"J2000\", 0)\n    {:ok, [x, y, z, dx, dy, dz], lt}\n\nMore info at\nhttps://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/spkgeo_c","ref":"Astro.Ephemeris.html#spkgeo/4-example"},{"type":"module","title":"Astro.Support","doc":"Support functions","ref":"Astro.Support.html"},{"type":"function","title":"Astro.Support.bodc2n/1","doc":"","ref":"Astro.Support.html#bodc2n/1"},{"type":"function","title":"Astro.Support.bodn2c/1","doc":"","ref":"Astro.Support.html#bodn2c/1"},{"type":"function","title":"Astro.Support.bodvcd/2","doc":"","ref":"Astro.Support.html#bodvcd/2"},{"type":"function","title":"Astro.Support.bodvrd/2","doc":"","ref":"Astro.Support.html#bodvrd/2"},{"type":"function","title":"Astro.Support.spkobj/1","doc":"","ref":"Astro.Support.html#spkobj/1"},{"type":"module","title":"Astro.Time","doc":"Module contains functions for manipulating time. It supports following time definitions:\n\n  - UTC\n  - International Atomic Time (TAI)\n  - Terrestrial Time (TT)\n  - Geocentric Coordinate Time (TCG)\n  - Barycentric Dynamic Time (TDB)\n  - Barycentric Coordinate Time (TCB)\n\nUnless specified differently all functions returns Julian Date as float number","ref":"Astro.Time.html"},{"type":"function","title":"Astro.Time.day2sec/1","doc":"Convert Julian Date to number of seconds past J2000","ref":"Astro.Time.html#day2sec/1"},{"type":"function","title":"Astro.Time.dtf2d/6","doc":"Convert Gregorian date tuple to Julian Date","ref":"Astro.Time.html#dtf2d/6"},{"type":"function","title":"Astro.Time.jd2dt/1","doc":"Convert Julian Date to Gregorian date tuple","ref":"Astro.Time.html#jd2dt/1"},{"type":"function","title":"Astro.Time.sec2day/1","doc":"Convert number of seconds past J2000 to Julian Date","ref":"Astro.Time.html#sec2day/1"},{"type":"function","title":"Astro.Time.str2et/1","doc":"Convert any datetime string to Ephemeris Time (ET) represented as number of seconds past J2000","ref":"Astro.Time.html#str2et/1"},{"type":"function","title":"Astro.Time.tai2tt/1","doc":"Convert International Atomic Time to Terrestrial Time (Julian Dates)","ref":"Astro.Time.html#tai2tt/1"},{"type":"function","title":"Astro.Time.tai2utc/1","doc":"Convert International Atomic Time to UTC (Julian Dates)","ref":"Astro.Time.html#tai2utc/1"},{"type":"function","title":"Astro.Time.tcb2tdb/1","doc":"Convert Barycentric Coordinate Time to Barycentric Dynamic Time (Julian Dates)","ref":"Astro.Time.html#tcb2tdb/1"},{"type":"function","title":"Astro.Time.tcg2tt/1","doc":"Convert Geocentric Coordinate Time to Terrestrial Time (Julian Dates)","ref":"Astro.Time.html#tcg2tt/1"},{"type":"function","title":"Astro.Time.tdb2tcb/1","doc":"Convert Barycentric Dynamic Time to Barycentric Coordinate Time (Julian Dates)","ref":"Astro.Time.html#tdb2tcb/1"},{"type":"function","title":"Astro.Time.tdb2tt/1","doc":"Convert Barycentric Dynamic Time to Terrestrial Time (Julian Dates)","ref":"Astro.Time.html#tdb2tt/1"},{"type":"function","title":"Astro.Time.to_datetime/1","doc":"","ref":"Astro.Time.html#to_datetime/1"},{"type":"function","title":"Astro.Time.to_julian_date/1","doc":"","ref":"Astro.Time.html#to_julian_date/1"},{"type":"function","title":"Astro.Time.tt2tai/1","doc":"Convert Terrestrial Time to International Atomic Time (Julian Dates)","ref":"Astro.Time.html#tt2tai/1"},{"type":"function","title":"Astro.Time.tt2tcg/1","doc":"Convert Terrestrial Time to Geocentric Coordinate Time (Julian Dates)","ref":"Astro.Time.html#tt2tcg/1"},{"type":"function","title":"Astro.Time.tt2tdb/1","doc":"Convert Terrestrial Time to Barycentric Dynamic Time (Julian Dates)","ref":"Astro.Time.html#tt2tdb/1"},{"type":"function","title":"Astro.Time.unitim/3","doc":"Convert epoch in one system to an another","ref":"Astro.Time.html#unitim/3"},{"type":"function","title":"Astro.Time.utc2et/1","doc":"Convert UTC datetime string to Ephemeris Time (ET) represented as number of seconds past J2000","ref":"Astro.Time.html#utc2et/1"},{"type":"function","title":"Astro.Time.utc2tai/1","doc":"Convert UTC to International Atomic Time (Julian Dates)","ref":"Astro.Time.html#utc2tai/1"},{"type":"task","title":"mix astro.kernels","doc":"Download some general SPICE kernels to the priv/kernels/ directory\n\nIf you want to download more kernels manually look here:\nhttps://naif.jpl.nasa.gov/pub/naif/generic_kernels/","ref":"Mix.Tasks.Astro.Kernels.html"},{"type":"extras","title":"Overview","doc":"# Astro\n\nLibrary to help working with [SPICE](https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/index.html)\nand [ERFA](https://github.com/liberfa/erfa) libraries","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"It is a bit more complicated then normal lib so pay attention:\n\n- instal ERFA library\n  -  \n- add `ex_astro` to `mix.exs`\n\n```elixir\n  def deps do\n    [\n      ...\n      {:ex_astro, \"~> 0.1\"},\n      ...\n    ]\n  end\n```\n\n- download SPICE kernels and add them to the config\n\n```bash\nmix astro.kernels\n```","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.1 (2024-01-07) - Changelog","doc":"- fix loading strings\n- new functions\n  - `bodvrd`","ref":"changelog.html#v0-2-1-2024-01-07"},{"type":"extras","title":"v0.2.0 (2024-01-07) - Changelog","doc":"- standardize all functions outputs to be same as in SPICE\n- return :ok/:error tuples\n- new functions\n  - `bodvcd`\n  - `oscelt`\n  - `conics`\n- more documentation","ref":"changelog.html#v0-2-0-2024-01-07"},{"type":"extras","title":"v0.1.0 (2024-01-03) - Changelog","doc":"- initial release","ref":"changelog.html#v0-1-0-2024-01-03"}],"content_type":"text/markdown"}